package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;

public class Holder extends ASN1Encodable {
   IssuerSerial baseCertificateID;
   GeneralNames entityName;
   ObjectDigestInfo objectDigestInfo;
   private int version = 1;

   public static Holder getInstance(Object obj) {
      if (obj instanceof Holder) {
         return (Holder)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new Holder((ASN1Sequence)obj);
      } else if (obj instanceof ASN1TaggedObject) {
         return new Holder((ASN1TaggedObject)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public Holder(ASN1TaggedObject tagObj) {
      int var2;
      if ((var2 = tagObj.getTagNo()) != 0) {
         if (var2 != 1) {
            throw new IllegalArgumentException("unknown tag in Holder");
         }

         this.entityName = GeneralNames.getInstance(tagObj, false);
      } else {
         this.baseCertificateID = IssuerSerial.getInstance(tagObj, false);
      }

      this.version = 0;
   }

   public Holder(ASN1Sequence seq) {
      if (seq.size() <= 3) {
         for(int var2 = 0; var2 != seq.size(); ++var2) {
            ASN1TaggedObject var3;
            int var4;
            if ((var4 = (var3 = ASN1TaggedObject.getInstance(seq.getObjectAt(var2))).getTagNo()) != 0) {
               if (var4 != 1) {
                  if (var4 != 2) {
                     throw new IllegalArgumentException("unknown tag in Holder");
                  }

                  this.objectDigestInfo = ObjectDigestInfo.getInstance(var3, false);
               } else {
                  this.entityName = GeneralNames.getInstance(var3, false);
               }
            } else {
               this.baseCertificateID = IssuerSerial.getInstance(var3, false);
            }
         }

         this.version = 1;
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public Holder(IssuerSerial baseCertificateID) {
      this.baseCertificateID = baseCertificateID;
   }

   public Holder(IssuerSerial baseCertificateID, int version) {
      this.baseCertificateID = baseCertificateID;
      this.version = version;
   }

   public Holder(GeneralNames entityName) {
      this.entityName = entityName;
   }

   public Holder(GeneralNames entityName, int version) {
      this.entityName = entityName;
      this.version = version;
   }

   public Holder(ObjectDigestInfo objectDigestInfo) {
      this.objectDigestInfo = objectDigestInfo;
   }

   public int getVersion() {
      return this.version;
   }

   public IssuerSerial getBaseCertificateID() {
      return this.baseCertificateID;
   }

   public GeneralNames getEntityName() {
      return this.entityName;
   }

   public ObjectDigestInfo getObjectDigestInfo() {
      return this.objectDigestInfo;
   }

   public DERObject toASN1Object() {
      if (this.version == 1) {
         ASN1EncodableVector var6;
         var6 = new ASN1EncodableVector.<init>();
         IssuerSerial var2;
         DERTaggedObject var3;
         if ((var2 = this.baseCertificateID) != null) {
            var3 = new DERTaggedObject.<init>(false, 0, var2);
            var6.add(var3);
         }

         GeneralNames var7;
         if ((var7 = this.entityName) != null) {
            var3 = new DERTaggedObject.<init>(false, 1, var7);
            var6.add(var3);
         }

         ObjectDigestInfo var5;
         if ((var5 = this.objectDigestInfo) != null) {
            DERTaggedObject var8;
            var8 = new DERTaggedObject.<init>(false, 2, var5);
            var6.add(var8);
         }

         return new DERSequence(var6);
      } else {
         GeneralNames var1;
         if ((var1 = this.entityName) != null) {
            return new DERTaggedObject(false, 1, var1);
         } else {
            IssuerSerial var4 = this.baseCertificateID;
            return new DERTaggedObject(false, 0, var4);
         }
      }
   }
}
